@@ -1,5 +1,12 @@
 #!/usr/bin/env python3
-# File: a2a_server/routes/handlers.py (Updated)
+# a2a_server/routes/handlers.py
+"""
+Per-handler route registration for the A2A server.
+
+This module registers routes for each handler discovered by the task manager,
+providing handler-specific endpoints for health checks, agent cards, and
+streaming responses.
+"""
 
 import logging
 from typing import List, Optional
@@ -12,18 +19,34 @@ from a2a_server.transport.sse import _create_sse_response
 # logger
 logger = logging.getLogger(__name__)
 
+
 def register_handler_routes(
     app: FastAPI,
     task_manager,
     handlers_config: dict
 ):
+    """
+    Register per-handler routes for each handler in the task manager.
+    
+    For each handler, this registers:
+    - GET /{handler_name} - Health endpoint with optional SSE streaming
+    - GET /{handler_name}/.well-known/agent.json - Agent card endpoint
+    
+    Args:
+        app: FastAPI application instance
+        task_manager: Task manager containing handlers
+        handlers_config: Configuration dict for handlers
+    """
     # per-handler GET health and streaming
     for handler_name in task_manager.get_handlers().keys():
+        
+        # Create handler health endpoint
         async def _handler_health(
             request: Request,
-            _h=handler_name,
+            _h=handler_name,  # Capture handler name in closure
             task_ids: Optional[List[str]] = Query(None)
         ):
+            """Handler health endpoint with optional SSE streaming."""
             if task_ids:
                 logger.debug(
                     "Upgrading GET /%s to SSE streaming: %r", _h, task_ids
@@ -41,6 +64,7 @@ def register_handler_routes(
                 "handler_agent_card": f"{base}/{_h}/.well-known/agent.json",
             }
 
+        # Register the health endpoint
         app.add_api_route(
             f"/{handler_name}",
             _handler_health,
@@ -48,22 +72,27 @@ def register_handler_routes(
             include_in_schema=False,
         )
 
-        async def _handler_card(request: Request, _h=handler_name):
+        # Create handler agent card endpoint
+        async def _handler_card(
+            request: Request, 
+            _h=handler_name  # Capture handler name in closure
+        ):
+            """Handler-specific agent card endpoint."""
             base = str(request.base_url).rstrip("/")
+            
+            # Get or create agent cards cache
             if not hasattr(app.state, "agent_cards"):
                 app.state.agent_cards = get_agent_cards(handlers_config, base)
+            
             card = app.state.agent_cards.get(_h)
             if card:
-                # Updated: Use model_dump() instead of dict()
+                # Use model_dump() for Pydantic v2 compatibility
                 return card.model_dump(exclude_none=True)
 
-            # fallback minimal agent-card, now with "mount"
+            # Fallback minimal agent-card
             return {
                 "name": _h.replace("_", " ").title(),
                 "description": f"A2A handler for {_h}",
-                # tell the client to mount under /<handler_name>
-                "mount": _h,
-                # base URL for this handler
                 "url": f"{base}/{_h}",
                 "version": "1.0.0",
                 "capabilities": {"streaming": True},
@@ -77,9 +106,12 @@ def register_handler_routes(
                 }],
             }
 
+        # Register the agent card endpoint
         app.add_api_route(
             f"/{handler_name}/.well-known/agent.json",
             _handler_card,
             methods=["GET"],
             include_in_schema=False,
-        )
\ No newline at end of file
+        )
+
+    logger.debug(f"Registered routes for {len(task_manager.get_handlers())} handlers")
\ No newline at end of file
