@@ -12,13 +12,13 @@ _bearer = HTTPBearer(auto_error=False)
 
 def require_admin_token(
     creds: HTTPAuthorizationCredentials | None = Security(_bearer),
-):  # noqa: D401 – imperative helper
+):  # noqa: D401 - imperative helper
     """Guard that **rejects** unless `Authorization: Bearer <token>` matches
     `$A2A_ADMIN_TOKEN`.  If the env-var is **unset** we assume *dev mode* and
     allow all traffic (so `pytest` keeps working).
     """
     expected = os.getenv("A2A_ADMIN_TOKEN")
-    if expected is None:  # dev‑mode shortcut
+    if expected is None:  # dev-mode shortcut
         return None
 
     if not creds or creds.credentials != expected:
