@@ -1,4 +1,4 @@
-# a2a_server/task_manager.py
+# a2a_server/tasks/task_manager.py
 from __future__ import annotations
 
 """
@@ -7,10 +7,14 @@ a2a_server.tasks.task_manager
 TaskManager refactored to use **asyncio.TaskGroup** (Python ≥ 3.11) and to be
 robust against post-cancellation events coming from slow / non-cooperative
 handlers.
+
+Added session_manager property for deduplication system.
 """
 
 import asyncio
 import logging
+import time
+import traceback  # ADDED: For call stack tracking
 from datetime import datetime, timezone
 from typing import Any, Dict, List, Optional
 from uuid import uuid4
@@ -27,7 +31,7 @@ from a2a_json_rpc.spec import (
     TextPart,
 )
 from a2a_server.pubsub import EventBus
-from a2a_server.tasks.task_handler import TaskHandler
+from a2a_server.tasks.handlers.task_handler import TaskHandler
 
 __all__ = [
     "TaskManager",
@@ -70,6 +74,29 @@ class TaskManager:
 
         self._lock = asyncio.Lock()
         self._tg: asyncio.TaskGroup | None = None
+        
+        # Session manager for deduplication (lazy-loaded)
+        self._session_manager = None
+
+    @property
+    def session_manager(self):
+        """
+        Get session manager for deduplication system.
+        Lazy-loads the session manager on first access.
+        """
+        if self._session_manager is None:
+            try:
+                from a2a_server.session_store_factory import build_session_manager
+                self._session_manager = build_session_manager()
+                logger.debug(f"✅ Loaded session manager for TaskManager: {type(self._session_manager).__name__}")
+            except ImportError as e:
+                logger.warning(f"❌ Could not import session store factory: {e}")
+                self._session_manager = None
+            except Exception as e:
+                logger.warning(f"❌ Could not create session manager: {e}")
+                self._session_manager = None
+                
+        return self._session_manager
 
     # ───────────────── handler registry ────────────────────────────────
 
@@ -123,6 +150,12 @@ class TaskManager:
     ) -> Task:
         canonical = id or task_id or str(uuid4())
 
+        # 🔧 DEBUG: Log every create_task call
+        logger.debug(f"🔧 TaskManager.create_task called: {canonical}")
+        logger.debug(f"   Handler: {handler_name}")
+        logger.debug(f"   Session: {session_id}")
+        logger.debug(f"   Active tasks: {len(self._active)}")
+
         async with self._lock:
             if canonical in self._tasks:
                 raise ValueError(f"Task {canonical} already exists")
@@ -142,7 +175,12 @@ class TaskManager:
             await self._bus.publish(TaskStatusUpdateEvent(id=canonical, status=task.status, final=False))
 
         await self._ensure_taskgroup()
+        
+        # 🔧 DEBUG: Log TaskGroup creation
+        logger.debug(f"🚀 Creating async task for {canonical} in TaskGroup")
         self._tg.create_task(self._run_task(canonical, hdl, user_msg, task.session_id))
+        logger.debug(f"✅ Task {canonical} created and started")
+        
         return task
 
     async def get_task(self, task_id: str) -> Task:
@@ -192,8 +230,18 @@ class TaskManager:
     # ───────────────── task runner ─────────────────────────────────────
 
     async def _run_task(self, task_id: str, handler: TaskHandler, user_msg: Message, session_id: str):
+        # 🔧 DEBUG: Log task runner entry
+        run_id = f"run-{int(time.time() * 1000) % 10000}"
+        logger.debug(f"🚀 _run_task ENTRY: {run_id}")
+        logger.debug(f"   Task ID: {task_id}")
+        logger.debug(f"   Handler: {handler.name}")
+        logger.debug(f"   Session: {session_id}")
+        
         try:
+            logger.debug(f"📨 [{run_id}] Calling handler.process_task for {task_id}")
             async for event in handler.process_task(task_id, user_msg, session_id):
+                logger.debug(f"📨 [{run_id}] Event from {handler.name}: {type(event).__name__}")
+                
                 if isinstance(event, TaskStatusUpdateEvent):
                     try:
                         await self.update_status(task_id, event.status.state, message=event.status.message)
@@ -204,6 +252,9 @@ class TaskManager:
                         await self.add_artifact(task_id, event.artifact)
                     except TaskNotFound:
                         logger.debug("Task %s vanished before artifact could be added", task_id)
+            
+            logger.debug(f"✅ [{run_id}] Task {task_id} processing completed")
+                        
         except asyncio.CancelledError:
             logger.info("Task %s cancelled", task_id)
             try:
@@ -218,6 +269,7 @@ class TaskManager:
             except InvalidTransition:
                 pass
         finally:
+            logger.debug(f"🏁 [{run_id}] Task {task_id} runner finished, cleaning up")
             self._active.pop(task_id, None)
 
     # ───────────────── shutdown / helpers ──────────────────────────────
@@ -229,3 +281,12 @@ class TaskManager:
 
     def tasks_by_state(self, state: TaskState) -> List[Task]:
         return [t for t in self._tasks.values() if t.status.state == state]
+
+    def get_deduplication_stats(self) -> Dict[str, Any]:
+        """Get statistics about deduplication system."""
+        return {
+            "session_manager_available": self.session_manager is not None,
+            "session_manager_type": type(self.session_manager).__name__ if self.session_manager else None,
+            "total_tasks": len(self._tasks),
+            "active_tasks": len(self._active)
+        }
\ No newline at end of file
